---
title: 나이스페이먼츠 해외결제 서비스 이용안내
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 해외결제
seo:
  title: 나이스페이먼츠 해외결제 서비스 이용안내
  description: >-
    나이스페이먼츠의 해외카드결제 서비스를 통한 해외결제 이용방법 안내드립니다. 나이스페이먼츠의 지원결제 수단 및 특징, 입점기준, 특약
    신청방법, 참고사항까지 자세한 정보를 확인해보세요.
  keywords:
    - 나이스페이먼츠
    - 해외결제
tags:
  - 나이스페이먼츠
  - 해외결제
pgCompanies:
  - 나이스페이먼츠
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="나이스페이먼츠를 통한 해외결제 이용방법 안내드립니다." />

### **나이스페이먼츠의 해외카드결제 서비스 이용안내**

1. **지원 결제수단**

- 해외카드 : VISA, MASTER, Unionpay

##### **2. 지원 서비스 특징**

- 지원가능 통화 : KRW (승인/정산) , USD (나이스페이측과 별도 협의필요)
- 결제방식 : KCP결제창을 띄우는 방식으로만 가능
- 지원가능언어 : 한국어, 영어, 중국어
- 정산방식 : 원화결제 - 원화정산

##### **3. 입점기준**

- 국내사업자로만 계약이 가능합니다. (해외 법인 사업자 계약불가)
- 나이스페이먼츠를 통해 해외카드 사용 특약을 맺은 후 서비스 사용이 가능합니다.
- 컨텐츠 상품도 입점심사을 받아볼 수 있습니다.

##### **4. 참고사항**

나이스페이먼츠의 경우에는 해외카드 결제 시 국내 카드 결제와 비슷하게 인증시스템(3D인증)을 거쳐야하기에\
인증 절차가 없는 해외 결제자들에게는 결제과정이 다소 불편할 수 있습니다.

<Callout content="나이스페이 고객센터로 문의하여 해외카드 서비스 신청
나이스페이 신규계약부서 : 1661-7335 - 3 혹은 pghelp@nicepay.co.kr 로 문의" title="특약 신청방법" icon="💡" />

<Callout title="V2 나이스페이먼츠 연동가이드 보러가기↗" />

<Callout title="V1 나이스페이먼츠 연동가이드 보러가기↗" />
